diff --git a/Lottery/AppShell.xaml b/Lottery/AppShell.xaml
index 6eefca0..7c44897 100644
--- a/Lottery/AppShell.xaml
+++ b/Lottery/AppShell.xaml
@@ -5,10 +5,10 @@
xmlns:x="http://schemas.microsoft.com/winfx/2009/xaml"
xmlns:local="clr-namespace:Lottery"
Shell.FlyoutBehavior="Disabled"
- Title="">
+ Title="Lottery Number Generator">
diff --git a/Lottery/MainPage.xaml b/Lottery/MainPage.xaml
index 7c1e704..8924a61 100644
--- a/Lottery/MainPage.xaml
+++ b/Lottery/MainPage.xaml
@@ -7,7 +7,7 @@
-
+
diff --git a/Lottery/MainPage.xaml.cs b/Lottery/MainPage.xaml.cs
index 7ebcc54..ffacbeb 100644
--- a/Lottery/MainPage.xaml.cs
+++ b/Lottery/MainPage.xaml.cs
@@ -16,10 +16,10 @@
InitializeComponent();
List lottos = ["UK Lotto", "EuroMillions", "Set For Life", "Thunderball"];
- LottoPicker.ItemsSource = lottos;
- LottoPicker.SelectedIndex = (int)DefaultLottery;
+ LotteryPicker.ItemsSource = lottos;
+ LotteryPicker.SelectedIndex = (int)DefaultLottery;
- Lottery = Lotteries[LottoPicker.SelectedIndex];
+ Lottery = Lotteries[LotteryPicker.SelectedIndex];
}
private void SpinButton_Clicked(object sender, EventArgs e)
@@ -43,14 +43,15 @@
}
break;
default:
- throw new LottoPickerException($"no NumbersLabel output defined for {numbers.Kind}");
+ throw new LotteryException($"no NumbersLabel output defined for {numbers.Kind}");
};
NumbersLabel.Text = string.Join("\t", output);
+ SemanticScreenReader.Announce(NumbersLabel.Text);
}
- private void LottoPicker_SelectedIndexChanged(object sender, EventArgs e)
+ private void LotteryPicker_SelectedIndexChanged(object sender, EventArgs e)
{
- Lottery = Lotteries[LottoPicker.SelectedIndex];
+ Lottery = Lotteries[LotteryPicker.SelectedIndex];
}
}
}
diff --git a/Lottery/Exception.cs b/Lottery/Exception.cs
index 5905777..26e61ba 100644
--- a/Lottery/Exception.cs
+++ b/Lottery/Exception.cs
@@ -1,9 +1,9 @@
namespace Lottery
{
///
/// Base Exception class for the LottoPicker app
///
- internal class LottoPickerException(string message) : Exception(message)
+ internal class LotteryException(string message) : Exception(message)
{
}
}
@@ -1,9 +1,9 @@
{
///
- /// Base Exception class for the LottoPicker app
+ /// Base Exception class for the Lottery app
///